==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Malĝusta pasvorto",
    "Saved" : "Konservita",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Authentication error" : "Aŭtentiga eraro",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "All" : "Ĉio",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Delete" : "Forigi",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "User documentation" : "Uzodokumentaro",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Open documentation" : "Malfermi la dokumentaron",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Version" : "Eldono",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Password" : "Pasvorto",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Show user backend" : "Montri uzantomotoron",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Unlimited" : "Senlima",
    "Other" : "Alia",
    "Quota" : "Kvoto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Malĝusta pasvorto",
    "Saved" : "Konservita",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Authentication error" : "Aŭtentiga eraro",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "All" : "Ĉio",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Delete" : "Forigi",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "User documentation" : "Uzodokumentaro",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Open documentation" : "Malfermi la dokumentaron",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Version" : "Eldono",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Password" : "Pasvorto",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Show user backend" : "Montri uzantomotoron",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Unlimited" : "Senlima",
    "Other" : "Alia",
    "Quota" : "Kvoto",
    "E-Mail" : "Retpoŝtadreso",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "Create" : "Krei"
},
"nplurals=2; plural=(n != 1);");
